<?php

/**
 * @param array $data
 *   this is the machine name for the component in question
 * @param array &$export
 *   array of all components to be exported
 * @param string $module_name
 *   The name of the feature module to be generated.
 * @return array
 *   The pipe array of further processors that should be called
 */
function paypal_donations_features_export($data, &$export, $module_name = '') {
  $export['dependencies']['features'] = 'features';
  $export['dependencies']['paypal_donations'] = 'paypal_donations';
  $export['features']['paypal_donations']['settings'] = 'PayPal donation settings';
  return $export;
}

/**
 * COMPONENT
 * @return array
 *   A keyed array of items, suitable for use with a FormAPI select or
 *   checkboxes element.
 */
function paypal_donations_features_export_options() {
  $items = array();
  $items['settings'] = t("PayPal donation settings");
  return $items;
}

/**
 * COMPONENT
 
 Render one or more component objects to code.
 *
 * @param string $module_name
 *   The name of the feature module to be exported.
 * @param array $data
 *   An array of machine name identifiers for the objects to be rendered.
 * @param array $export
 *   The full export array of the current feature being exported. This is only
 *   passed when hook_features_export_render() is invoked for an actual feature
 *   update or recreate, not during state checks or other operations.
 * @return array
 *   An associative array of rendered PHP code where the key is the name of the
 *   hook that should wrap the PHP code. The hook should not include the name
 *   of the module, e.g. the key for `hook_example` should simply be `example`.
 */
function paypal_donations_features_export_render($module, $data) {
  $variable_keys = paypal_donations__variable_list();
  $code = array();
  
  foreach( $variable_keys as $vk ){
    $code[$vk] = variable_get($vk,'');
  }

  $code = "  return " . features_var_export($code, '  ') . ";";
  return array('paypal_donations_features_settings' => $code);
}

/**
  COMPONENT
 * Implements hook_features_revert().
 */
function paypal_donations_features_revert($module) {
  paypal_donations_features_rebuild($module);
}
 
/**
  COMPONENT
 * Implements hook_features_rebuild().
 *
 * Rebuilds @font-your-face fonts from code defaults.
 */
function paypal_donations_features_rebuild($module) {
  $settings = module_invoke($module, 'paypal_donations_features_settings');
  foreach ($settings as $key => $val) {
    variable_set($key, $val);
  }
}


